"""配置管理模块"""
import os
from dataclasses import dataclass
from typing import Tuple, List, Optional


@dataclass
class ModelConfig:
    """模型配置"""
    model_path: str = 'D:/PythonProject/ModelEvaluator/data/models/UAV-250411.onnx'
    input_size: Tuple[int, int] = (640, 640)  # width, height
    mean: Tuple[float, float, float] = (0.485, 0.456, 0.406)
    std: Tuple[float, float, float] = (0.229, 0.224, 0.225)
    providers: List[str] = None
    
    def __post_init__(self):
        if self.providers is None:
            self.providers = ['CUDAExecutionProvider', 'CPUExecutionProvider']


@dataclass
class DetectionConfig:
    """检测配置"""
    confidence_threshold: float = 0.5
    iou_threshold: float = 0.4
    max_bbox_ratio: float = 0.5
    class_names: dict = None
    
    def __post_init__(self):
        if self.class_names is None:
            self.class_names = {0: 'UAV'}


@dataclass
class OutputConfig:
    """输出配置"""
    output_dir: Optional[str] = None
    save_empty: bool = False
    create_timestamp_dir: bool = True
    
    def get_output_dir(self, input_dir: Optional[str] = None) -> str:
        """获取输出目录路径"""
        from datetime import datetime
        
        output_base = os.path.join(os.path.dirname(__file__), '..', '..', 'Output')
        os.makedirs(output_base, exist_ok=True)
        
        if self.create_timestamp_dir:
            timestamp = datetime.now().strftime('%m%d%H%M%S')
            if self.output_dir is None and input_dir is not None:
                return os.path.join(output_base, f"{os.path.basename(os.path.normpath(input_dir))}_{timestamp}")
            else:
                return os.path.join(output_base, self.output_dir or f"output_{timestamp}")
        else:
            return os.path.join(output_base, self.output_dir or "output")


@dataclass
class AppConfig:
    """应用配置"""
    model: ModelConfig = None
    detection: DetectionConfig = None
    output: OutputConfig = None
    false_positive_features_path: str = 'false_positive_features.pkl'
    
    def __post_init__(self):
        if self.model is None:
            self.model = ModelConfig()
        if self.detection is None:
            self.detection = DetectionConfig()
        if self.output is None:
            self.output = OutputConfig()